@@ -26,18 +26,27 @@ Server object variables:
 	server.reserved_drive_paths
 	server.adding_cpu_requires_reboot
 	server.adding_memory_requires_reboot
+	server.created_by
+	server.created_date - POSIX time
+	server.modified_by
+	server.modified_date - POSIX time
 	server.dirty - bool indicating whether server object is different than cloud object
 
 Server object variables available but access subject to change with future releases:
 
 	server.custom_fields
-	server.change_info
+	server.partitions
 	server.alert_policies
 	server.ip_addresses
+	server.managed_apps
 
 """
 
 # vCur:
+# TODO - disks
+# TODO - add disk
+# TODO - grow disk
+# TODO - delete disk
 # TODO - Link to Public IP class
 
 # vNext:
@@ -163,6 +172,7 @@ class Server(object):
 
 		self.id = id
 		self.capabilities = None
+		self.disks = None
 		self.dirty = False
 
 		if alias:  self.alias = alias
@@ -187,6 +197,9 @@ class Server(object):
 		self.data = clc.v2.API.Call('GET','servers/%s/%s' % (self.alias,self.id),{})
 
 		try:
+			self.data['changeInfo']['createdDate'] = clc.v2.time_utils.ZuluTSToSeconds(self.data['changeInfo']['createdDate'])
+			self.data['changeInfo']['modifiedDate'] = clc.v2.time_utils.ZuluTSToSeconds(self.data['changeInfo']['modifiedDate'])
+
 			# API call switches between GB and MB.  Change to all references are in GB and we drop the units
 			self.data['details']['memoryGB'] = int(math.floor(self.data['details']['memoryMB']/1024))
 		except:
@@ -206,6 +219,7 @@ class Server(object):
 
 		if key in self.data:  return(self.data[key])
 		elif key in self.data['details']:  return(self.data['details'][key])
+		elif key in self.data['changeInfo']:  return(self.data['changeInfo'][key])
 		elif key in ("reservedDrivePaths", "addingCpuRequiresReboot", "addingMemoryRequiresReboot"):  return(self._Capabilities()[key])
 		else:  raise(AttributeError("'%s' instance has no attribute '%s'" % (self.__class__.__name__,key)))
 
@@ -236,6 +250,20 @@ class Server(object):
 		return(clc.v2.Group(id=self.groupId,alias=self.alias))
 
 	
+	def Disks(self):
+		"""Return disks object associated with server.
+
+		>>> clc.v2.Server("WA1BTDIX01").Disks()
+		<clc.APIv2.disk.Disks object at 0x10feea190>
+
+		"""
+
+		if not self.disks:  self.disks = clc.v2.Disks(server=self,disks_lst=self.data['details']['disks'])
+		
+		return(self.disks)
+
+
+
 	def Alerts(self):
 		"""Returns an Alerts object containing all alerts mapped to this server.
 
